@@ -16,21 +16,25 @@ import sys
 import textwrap
 from pathlib import Path
 from sys import stdin
-from typing import Any, Callable
+from typing import TYPE_CHECKING, Any, Callable
 
 import click
 import requests
 import urllib3
 import yaml
+from typing_extensions import deprecated
 
 from anta.cli.console import console
 from anta.cli.utils import ExitCode
 from anta.inventory import AntaInventory
 from anta.inventory.models import AntaInventoryHost, AntaInventoryInput
-from anta.models import AntaTest
+from anta.models import AntaCommand, AntaTest
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
+if TYPE_CHECKING:
+    from anta.catalog import AntaCatalog
+
 logger = logging.getLogger(__name__)
 
 
@@ -231,7 +235,240 @@ def create_inventory_from_ansible(inventory: Path, output: Path, ansible_group:
     write_inventory_to_file(ansible_hosts, output)
 
 
-def explore_package(module_name: str, test_name: str | None = None, *, short: bool = False, count: bool = False) -> int:
+def _explore_package(module_name: str, test_name: str | None = None, *, short: bool = False, count: bool = False) -> list[type[AntaTest]]:
+    """Parse ANTA test submodules recursively and return a list of the found AntaTest.
+
+    Parameters
+    ----------
+    module_name
+        Name of the module to explore (e.g., 'anta.tests.routing.bgp').
+    test_name
+        If provided, only show tests starting with this name.
+    short
+        If True, only print test names without their inputs.
+    count
+        If True, only count the tests.
+
+    Returns
+    -------
+    list[type[AntaTest]]:
+        A list of the AntaTest found.
+    """
+    result: list[type[AntaTest]] = []
+    try:
+        module_spec = importlib.util.find_spec(module_name)
+    except ModuleNotFoundError:
+        # Relying on module_spec check below.
+        module_spec = None
+    except ImportError as e:
+        msg = "`--module <module>` option does not support relative imports"
+        raise ValueError(msg) from e
+
+    # Giving a second chance adding CWD to PYTHONPATH
+    if module_spec is None:
+        try:
+            logger.info("Could not find module `%s`, injecting CWD in PYTHONPATH and retrying...", module_name)
+            sys.path = [str(Path.cwd()), *sys.path]
+            module_spec = importlib.util.find_spec(module_name)
+        except ImportError:
+            module_spec = None
+
+    if module_spec is None or module_spec.origin is None:
+        msg = f"Module `{module_name}` was not found!"
+        raise ValueError(msg)
+
+    if module_spec.submodule_search_locations:
+        for _, sub_module_name, ispkg in pkgutil.walk_packages(module_spec.submodule_search_locations):
+            qname = f"{module_name}.{sub_module_name}"
+            if ispkg:
+                result.extend(_explore_package(qname, test_name=test_name, short=short, count=count))
+                continue
+            result.extend(find_tests_in_module(qname, test_name))
+
+    else:
+        result.extend(find_tests_in_module(module_spec.name, test_name))
+
+    return result
+
+
+def find_tests_in_module(qname: str, test_name: str | None) -> list[type[AntaTest]]:
+    """Return the list of AntaTest in the passed module qname, potentially filtering on test_name.
+
+    Parameters
+    ----------
+    qname
+        Name of the module to explore (e.g., 'anta.tests.routing.bgp').
+    test_name
+        If provided, only show tests starting with this name.
+
+    Returns
+    -------
+    list[type[AntaTest]]:
+        A list of the AntaTest found in the module.
+    """
+    results: list[type[AntaTest]] = []
+    try:
+        qname_module = importlib.import_module(qname)
+    except (AssertionError, ImportError) as e:
+        msg = f"Error when importing `{qname}` using importlib!"
+        raise ValueError(msg) from e
+
+    for _name, obj in inspect.getmembers(qname_module):
+        # Only retrieves the subclasses of AntaTest
+        if not inspect.isclass(obj) or not issubclass(obj, AntaTest) or obj == AntaTest:
+            continue
+        if test_name and not obj.name.startswith(test_name):
+            continue
+        results.append(obj)
+
+    return results
+
+
+def _filter_tests_via_catalog(tests: list[type[AntaTest]], catalog: AntaCatalog) -> list[type[AntaTest]]:
+    """Return the filtered list of tests present in the catalog.
+
+    Parameters
+    ----------
+    tests:
+        List of tests.
+    catalog:
+        The AntaCatalog to use as filtering.
+
+    Returns
+    -------
+    list[type[AntaTest]]:
+        The filtered list of tests containing uniquely the tests found in the catalog.
+    """
+    catalog_test_names = {test.test.name for test in catalog.tests}
+    return [test for test in tests if test.name in catalog_test_names]
+
+
+def print_tests(tests: list[type[AntaTest]], *, short: bool = False) -> None:
+    """Print a list of AntaTest.
+
+    Parameters
+    ----------
+    tests
+        A list of AntaTest subclasses.
+    short
+        If True, only print test names without their inputs.
+    """
+
+    def module_name(test: type[AntaTest]) -> str:
+        """Return the module name for the input test.
+
+        Used to group the test by module.
+        """
+        return test.__module__
+
+    from itertools import groupby
+
+    for module, module_tests in groupby(tests, module_name):
+        console.print(f"{module}:")
+        for test in module_tests:
+            print_test(test, short=short)
+
+
+def print_test(test: type[AntaTest], *, short: bool = False) -> None:
+    """Print a single test.
+
+    Parameters
+    ----------
+    test
+        the representation of the AntaTest as returned by inspect.getmembers
+    short
+        If True, only print test names without their inputs.
+    """
+    if not test.__doc__ or (example := extract_examples(test.__doc__)) is None:
+        msg = f"Test {test.name} in module {test.__module__} is missing an Example"
+        raise LookupError(msg)
+    # Picking up only the inputs in the examples
+    # Need to handle the fact that we nest the routing modules in Examples.
+    # This is a bit fragile.
+    inputs = example.split("\n")
+    test_name_lines = [i for i, input_entry in enumerate(inputs) if test.name in input_entry]
+    if not test_name_lines:
+        msg = f"Could not find the name of the test '{test.name}' in the Example section in the docstring."
+        raise ValueError(msg)
+    for list_index, line_index in enumerate(test_name_lines):
+        end = test_name_lines[list_index + 1] if list_index + 1 < len(test_name_lines) else -1
+        console.print(f"  {inputs[line_index].strip()}")
+        # Injecting the description for the first example
+        if list_index == 0:
+            console.print(f"      # {test.description}", soft_wrap=True)
+        if not short and len(inputs) > line_index + 2:  # There are params
+            console.print(textwrap.indent(textwrap.dedent("\n".join(inputs[line_index + 1 : end])), " " * 6))
+
+
+def extract_examples(docstring: str) -> str | None:
+    """Extract the content of the Example section in a Numpy docstring.
+
+    Returns
+    -------
+    str | None
+        The content of the section if present, None if the section is absent or empty.
+    """
+    pattern = r"Examples\s*--------\s*(.*)(?:\n\s*\n|\Z)"
+    match = re.search(pattern, docstring, flags=re.DOTALL)
+    return match[1].strip() if match and match[1].strip() != "" else None
+
+
+def _print_commands(tests: list[type[AntaTest]]) -> None:
+    """Print a list of commands per module and per test.
+
+    Parameters
+    ----------
+    tests
+        A list of AntaTest subclasses.
+    """
+
+    def module_name(test: type[AntaTest]) -> str:
+        """Return the module name for the input test.
+
+        Used to group the test by module.
+        """
+        return test.__module__
+
+    from itertools import groupby
+
+    for module, module_tests in groupby(tests, module_name):
+        console.print(f"{module}:")
+        for test in module_tests:
+            console.print(f"  - {test.name}:")
+            for command in test.commands:
+                if isinstance(command, AntaCommand):
+                    console.print(f"    - {command.command}")
+                else:  # isinstance(command, AntaTemplate):
+                    console.print(f"    - {command.template}")
+
+
+def _get_unique_commands(tests: list[type[AntaTest]]) -> set[str]:
+    """Return a set of unique commands used by the tests.
+
+    Parameters
+    ----------
+    tests
+        A list of AntaTest subclasses.
+
+    Returns
+    -------
+    set[str]
+        A set of commands or templates used by each test.
+    """
+    result: set[str] = set()
+
+    for test in tests:
+        for command in test.commands:
+            if isinstance(command, AntaCommand):
+                result.add(command.command)
+            else:  # isinstance(command, AntaTemplate):
+                result.add(command.template)
+
+    return result
+
+
+@deprecated("This function is deprecated, use `_explore_package`. This will be removed in ANTA v2.0.0.", category=DeprecationWarning)
+def explore_package(module_name: str, test_name: str | None = None, *, short: bool = False, count: bool = False) -> int:  # pragma: no cover
     """Parse ANTA test submodules recursively and print AntaTest examples.
 
     Parameters
@@ -287,7 +524,8 @@ def explore_package(module_name: str, test_name: str | None = None, *, short: bo
     return tests_found
 
 
-def find_tests_examples(qname: str, test_name: str | None, *, short: bool = False, count: bool = False) -> int:
+@deprecated("This function is deprecated, use `find_tests_in_module`. This will be removed in ANTA v2.0.0.", category=DeprecationWarning)
+def find_tests_examples(qname: str, test_name: str | None, *, short: bool = False, count: bool = False) -> int:  # pragma: no cover
     """Print tests from `qname`, filtered by `test_name` if provided.
 
     Parameters
@@ -331,47 +569,3 @@ def find_tests_examples(qname: str, test_name: str | None, *, short: bool = Fals
         print_test(obj, short=short)
 
     return tests_found
-
-
-def print_test(test: type[AntaTest], *, short: bool = False) -> None:
-    """Print a single test.
-
-    Parameters
-    ----------
-    test
-        the representation of the AntaTest as returned by inspect.getmembers
-    short
-        If True, only print test names without their inputs.
-    """
-    if not test.__doc__ or (example := extract_examples(test.__doc__)) is None:
-        msg = f"Test {test.name} in module {test.__module__} is missing an Example"
-        raise LookupError(msg)
-    # Picking up only the inputs in the examples
-    # Need to handle the fact that we nest the routing modules in Examples.
-    # This is a bit fragile.
-    inputs = example.split("\n")
-    test_name_lines = [i for i, input_entry in enumerate(inputs) if test.name in input_entry]
-    if not test_name_lines:
-        msg = f"Could not find the name of the test '{test.name}' in the Example section in the docstring."
-        raise ValueError(msg)
-    for list_index, line_index in enumerate(test_name_lines):
-        end = test_name_lines[list_index + 1] if list_index + 1 < len(test_name_lines) else -1
-        console.print(f"  {inputs[line_index].strip()}")
-        # Injecting the description for the first example
-        if list_index == 0:
-            console.print(f"      # {test.description}", soft_wrap=True)
-        if not short and len(inputs) > line_index + 2:  # There are params
-            console.print(textwrap.indent(textwrap.dedent("\n".join(inputs[line_index + 1 : end])), " " * 6))
-
-
-def extract_examples(docstring: str) -> str | None:
-    """Extract the content of the Example section in a Numpy docstring.
-
-    Returns
-    -------
-    str | None
-        The content of the section if present, None if the section is absent or empty.
-    """
-    pattern = r"Examples\s*--------\s*(.*)(?:\n\s*\n|\Z)"
-    match = re.search(pattern, docstring, flags=re.DOTALL)
-    return match[1].strip() if match and match[1].strip() != "" else None
