@@ -13,7 +13,7 @@ from typing import ClassVar, TypeVar
 from pydantic import Field, field_validator
 from pydantic_extra_types.mac_address import MacAddress
 
-from anta.custom_types import Interface, Percent, PositiveInteger
+from anta.custom_types import Interface, InterfaceType, Percent, PortChannelInterface, PositiveInteger
 from anta.decorators import skip_on_platforms
 from anta.input_models.interfaces import InterfaceDetail, InterfaceState
 from anta.models import AntaCommand, AntaTemplate, AntaTest
@@ -25,17 +25,62 @@ BPS_GBPS_CONVERSIONS = 1000000000
 T = TypeVar("T", bound=InterfaceState)
 
 
+def _is_interface_ignored(interface: str, ignored_interfaces: list[str] | None = None) -> bool | None:
+    """Verify if an interface is present in the ignored interfaces list.
+
+    Parameters
+    ----------
+    interface
+        This is a string containing the interface name.
+    ignored_interfaces
+         A list containing the interfaces or interface types to ignore.
+
+    Returns
+    -------
+    bool
+        True if the interface is in the list of ignored interfaces, false otherwise.
+    Example
+    -------
+    ```python
+    >>> _is_interface_ignored(interface="Ethernet1", ignored_interfaces=["Ethernet", "Port-Channel1"])
+    True
+    >>> _is_interface_ignored(interface="Ethernet2", ignored_interfaces=["Ethernet1", "Port-Channel"])
+    False
+    >>> _is_interface_ignored(interface="Port-Channel1", ignored_interfaces=["Ethernet1", "Port-Channel"])
+    True
+     >>> _is_interface_ignored(interface="Ethernet1/1", ignored_interfaces: ["Ethernet1/1", "Port-Channel"])
+    True
+    >>> _is_interface_ignored(interface="Ethernet1/1", ignored_interfaces: ["Ethernet1", "Port-Channel"])
+    False
+    >>> _is_interface_ignored(interface="Ethernet1.100", ignored_interfaces: ["Ethernet1.100", "Port-Channel"])
+    True
+    ```
+    """
+    interface_prefix = re.findall(r"^[a-zA-Z-]+", interface, re.IGNORECASE)[0]
+    interface_exact_match = False
+    if ignored_interfaces:
+        for ignored_interface in ignored_interfaces:
+            if interface == ignored_interface:
+                interface_exact_match = True
+                break
+        return bool(any([interface_exact_match, interface_prefix in ignored_interfaces]))
+    return None
+
+
 class VerifyInterfaceUtilization(AntaTest):
     """Verifies that the utilization of interfaces is below a certain threshold.
 
     Load interval (default to 5 minutes) is defined in device configuration.
-    This test has been implemented for full-duplex interfaces only.
+
+    !!! warning
+        This test has been implemented for full-duplex interfaces only.
 
     Expected Results
     ----------------
     * Success: The test will pass if all interfaces have a usage below the threshold.
-    * Failure: The test will fail if one or more interfaces have a usage above the threshold.
-    * Error: The test will error out if the device has at least one non full-duplex interface.
+    * Failure: If any of the following occur:
+        - One or more interfaces have a usage above the threshold.
+        - The device has at least one non full-duplex interface.
 
     Examples
     --------
@@ -43,6 +88,9 @@ class VerifyInterfaceUtilization(AntaTest):
     anta.tests.interfaces:
       - VerifyInterfaceUtilization:
           threshold: 70.0
+          ignored_interfaces:
+            - Ethernet1
+            - Port-Channel1
     ```
     """
 
@@ -56,7 +104,9 @@ class VerifyInterfaceUtilization(AntaTest):
         """Input model for the VerifyInterfaceUtilization test."""
 
         threshold: Percent = 75.0
-        """Interface utilization threshold above which the test will fail. Defaults to 75%."""
+        """Interface utilization threshold above which the test will fail."""
+        ignored_interfaces: list[InterfaceType | Interface] | None = None
+        """A list of interfaces or interface types like Management which will ignore all Management interfaces."""
 
     @AntaTest.anta_test
     def test(self) -> None:
@@ -67,12 +117,23 @@ class VerifyInterfaceUtilization(AntaTest):
         interfaces = self.instance_commands[1].json_output
 
         for intf, rate in rates["interfaces"].items():
+            interface_data = []
+            # Verification is skipped if the interface is in the ignored interfaces list.
+            if _is_interface_ignored(intf, self.inputs.ignored_interfaces):
+                continue
+
             # The utilization logic has been implemented for full-duplex interfaces only
-            if ((duplex := (interface := interfaces["interfaces"][intf]).get("duplex", None)) is not None and duplex != duplex_full) or (
-                (members := interface.get("memberInterfaces", None)) is not None and any(stats["duplex"] != duplex_full for stats in members.values())
-            ):
-                self.result.is_failure(f"Interface {intf} or one of its member interfaces is not Full-Duplex. VerifyInterfaceUtilization has not been implemented.")
-                return
+            if not all([duplex := (interface := interfaces["interfaces"][intf]).get("duplex", None), duplex == duplex_full]):
+                if (members := interface.get("memberInterfaces", None)) is None:
+                    self.result.is_failure(f"Interface: {intf} - Test not implemented for non-full-duplex interfaces - Expected: {duplex_full} Actual: {duplex}")
+                    continue
+                interface_data = [(member_interface, state) for member_interface, stats in members.items() if (state := stats["duplex"]) != duplex_full]
+
+            for member_interface in interface_data:
+                self.result.is_failure(
+                    f"Interface: {intf} Member Interface: {member_interface[0]} - Test not implemented for non-full-duplex interfaces - Expected: {duplex_full}"
+                    f" Actual: {member_interface[1]}"
+                )
 
             if (bandwidth := interfaces["interfaces"][intf]["bandwidth"]) == 0:
                 self.logger.debug("Interface %s has been ignored due to null bandwidth value", intf)
@@ -106,12 +167,21 @@ class VerifyInterfaceErrors(AntaTest):
     categories: ClassVar[list[str]] = ["interfaces"]
     commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaCommand(command="show interfaces counters errors", revision=1)]
 
+    class Input(AntaTest.Input):
+        """Input model for the VerifyInterfaceErrors test."""
+
+        ignored_interfaces: list[InterfaceType | Interface] | None = None
+        """A list of interfaces or interface types like Management which will ignore all Management interfaces."""
+
     @AntaTest.anta_test
     def test(self) -> None:
         """Main test function for VerifyInterfaceErrors."""
         self.result.is_success()
         command_output = self.instance_commands[0].json_output
         for interface, counters in command_output["interfaceErrorCounters"].items():
+            # Verification is skipped if the interface is in the ignored interfaces list.
+            if _is_interface_ignored(interface, self.inputs.ignored_interfaces):
+                continue
             counters_data = [f"{counter}: {value}" for counter, value in counters.items() if value > 0]
             if counters_data:
                 self.result.is_failure(f"Interface: {interface} - Non-zero error counter(s) - {', '.join(counters_data)}")
@@ -130,18 +200,30 @@ class VerifyInterfaceDiscards(AntaTest):
     ```yaml
     anta.tests.interfaces:
       - VerifyInterfaceDiscards:
+          ignored_interfaces:
+            - Ethernet
+            - Port-Channel1
     ```
     """
 
     categories: ClassVar[list[str]] = ["interfaces"]
     commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaCommand(command="show interfaces counters discards", revision=1)]
 
+    class Input(AntaTest.Input):
+        """Input model for the VerifyInterfaceDiscards test."""
+
+        ignored_interfaces: list[InterfaceType | Interface] | None = None
+        """A list of interfaces or interface types like Management which will ignore all Management interfaces."""
+
     @AntaTest.anta_test
     def test(self) -> None:
         """Main test function for VerifyInterfaceDiscards."""
         self.result.is_success()
         command_output = self.instance_commands[0].json_output
         for interface, interface_data in command_output["interfaces"].items():
+            # Verification is skipped if the interface is in the ignored interfaces list.
+            if _is_interface_ignored(interface, self.inputs.ignored_interfaces):
+                continue
             counters_data = [f"{counter}: {value}" for counter, value in interface_data.items() if value > 0]
             if counters_data:
                 self.result.is_failure(f"Interface: {interface} - Non-zero discard counter(s): {', '.join(counters_data)}")
@@ -164,16 +246,22 @@ class VerifyInterfaceErrDisabled(AntaTest):
     """
 
     categories: ClassVar[list[str]] = ["interfaces"]
-    commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaCommand(command="show interfaces status", revision=1)]
+    commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaCommand(command="show interfaces status errdisabled", revision=1)]
 
     @AntaTest.anta_test
     def test(self) -> None:
         """Main test function for VerifyInterfaceErrDisabled."""
         self.result.is_success()
         command_output = self.instance_commands[0].json_output
-        for interface, value in command_output["interfaceStatuses"].items():
-            if value["linkStatus"] == "errdisabled":
-                self.result.is_failure(f"Interface: {interface} - Link status Error disabled")
+        if not (interface_details := get_value(command_output, "interfaceStatuses")):
+            return
+
+        for interface, value in interface_details.items():
+            if causes := value.get("causes"):
+                msg = f"Interface: {interface} - Error disabled - Causes: {', '.join(causes)}"
+                self.result.is_failure(msg)
+                continue
+            self.result.is_failure(f"Interface: {interface} - Error disabled")
 
 
 class VerifyInterfacesStatus(AntaTest):
@@ -276,7 +364,7 @@ class VerifyStormControlDrops(AntaTest):
     categories: ClassVar[list[str]] = ["interfaces"]
     commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaCommand(command="show storm-control", revision=1)]
 
-    @skip_on_platforms(["cEOSLab", "vEOS-lab", "cEOSCloudLab"])
+    @skip_on_platforms(["cEOSLab", "vEOS-lab", "cEOSCloudLab", "vEOS"])
     @AntaTest.anta_test
     def test(self) -> None:
         """Main test function for VerifyStormControlDrops."""
@@ -305,18 +393,31 @@ class VerifyPortChannels(AntaTest):
     ```yaml
     anta.tests.interfaces:
       - VerifyPortChannels:
+          ignored_interfaces:
+            - Port-Channel1
+            - Port-Channel2
+
     ```
     """
 
     categories: ClassVar[list[str]] = ["interfaces"]
     commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaCommand(command="show port-channel", revision=1)]
 
+    class Input(AntaTest.Input):
+        """Input model for the VerifyPortChannels test."""
+
+        ignored_interfaces: list[PortChannelInterface] | None = None
+        """A list of port-channel interfaces to ignore."""
+
     @AntaTest.anta_test
     def test(self) -> None:
         """Main test function for VerifyPortChannels."""
         self.result.is_success()
         command_output = self.instance_commands[0].json_output
         for port_channel, port_channel_details in command_output["portChannels"].items():
+            # Verification is skipped if the interface is in the ignored interfaces list.
+            if _is_interface_ignored(port_channel, self.inputs.ignored_interfaces):
+                continue
             # Verify that the no inactive ports in all port channels.
             if inactive_ports := port_channel_details["inactivePorts"]:
                 self.result.is_failure(f"{port_channel} - Inactive port(s) - {', '.join(inactive_ports.keys())}")
@@ -335,18 +436,30 @@ class VerifyIllegalLACP(AntaTest):
     ```yaml
     anta.tests.interfaces:
       - VerifyIllegalLACP:
+          ignored_interfaces:
+            - Port-Channel1
+            - Port-Channel2
     ```
     """
 
     categories: ClassVar[list[str]] = ["interfaces"]
     commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaCommand(command="show lacp counters all-ports", revision=1)]
 
+    class Input(AntaTest.Input):
+        """Input model for the VerifyIllegalLACP test."""
+
+        ignored_interfaces: list[PortChannelInterface] | None = None
+        """A list of port-channel interfaces to ignore."""
+
     @AntaTest.anta_test
     def test(self) -> None:
         """Main test function for VerifyIllegalLACP."""
         self.result.is_success()
         command_output = self.instance_commands[0].json_output
         for port_channel, port_channel_dict in command_output["portChannels"].items():
+            # Verification is skipped if the interface is in the ignored interfaces list.
+            if _is_interface_ignored(port_channel, self.inputs.ignored_interfaces):
+                continue
             for interface, interface_details in port_channel_dict["interfaces"].items():
                 # Verify that the no illegal LACP packets in all port channels.
                 if interface_details["illegalRxCount"] != 0:
@@ -431,11 +544,9 @@ class VerifySVI(AntaTest):
 
 
 class VerifyL3MTU(AntaTest):
-    """Verifies the global layer 3 Maximum Transfer Unit (MTU) for all L3 interfaces.
+    """Verifies the L3 MTU of routed interfaces.
 
-    Test that L3 interfaces are configured with the correct MTU. It supports Ethernet, Port Channel and VLAN interfaces.
-
-    You can define a global MTU to check, or an MTU per interface and you can also ignored some interfaces.
+    Test that layer 3 (routed) interfaces are configured with the correct MTU.
 
     Expected Results
     ----------------
@@ -449,9 +560,11 @@ class VerifyL3MTU(AntaTest):
       - VerifyL3MTU:
           mtu: 1500
           ignored_interfaces:
-              - Vxlan1
+              - Management  # Ignore all Management interfaces
+              - Ethernet2.100
+              - Ethernet1/1
           specific_mtu:
-              - Ethernet1: 2500
+              - Ethernet10: 9200
     ```
     """
 
@@ -463,33 +576,31 @@ class VerifyL3MTU(AntaTest):
         """Input model for the VerifyL3MTU test."""
 
         mtu: int = 1500
-        """Default MTU we should have configured on all non-excluded interfaces. Defaults to 1500."""
-        ignored_interfaces: list[str] = Field(default=["Management", "Loopback", "Vxlan", "Tunnel"])
-        """A list of L3 interfaces to ignore"""
-        specific_mtu: list[dict[str, int]] = Field(default=[])
-        """A list of dictionary of L3 interfaces with their specific MTU configured"""
+        """Expected L3 MTU configured on all non-excluded interfaces."""
+        ignored_interfaces: list[InterfaceType | Interface] = Field(default=["Dps", "Fabric", "Loopback", "Management", "Recirc-Channel", "Tunnel", "Vxlan"])
+        """A list of L3 interfaces or interfaces types like Loopback, Tunnel which will ignore all Loopback and Tunnel interfaces.
+
+        Takes precedence over the `specific_mtu` field."""
+        specific_mtu: list[dict[Interface, int]] = Field(default=[])
+        """A list of dictionary of L3 interfaces with their expected L3 MTU configured."""
 
     @AntaTest.anta_test
     def test(self) -> None:
         """Main test function for VerifyL3MTU."""
         self.result.is_success()
         command_output = self.instance_commands[0].json_output
-        # Set list of interfaces with specific settings
-        specific_interfaces: list[str] = []
-        if self.inputs.specific_mtu:
-            for d in self.inputs.specific_mtu:
-                specific_interfaces.extend(d)
-        for interface, values in command_output["interfaces"].items():
-            if re.findall(r"[a-z]+", interface, re.IGNORECASE)[0] not in self.inputs.ignored_interfaces and values["forwardingModel"] == "routed":
-                if interface in specific_interfaces:
-                    invalid_mtu = next(
-                        (values["mtu"] for custom_data in self.inputs.specific_mtu if values["mtu"] != (expected_mtu := custom_data[interface])), None
-                    )
-                    if invalid_mtu:
-                        self.result.is_failure(f"Interface: {interface} - Incorrect MTU - Expected: {expected_mtu} Actual: {invalid_mtu}")
-                # Comparison with generic setting
-                elif values["mtu"] != self.inputs.mtu:
-                    self.result.is_failure(f"Interface: {interface} - Incorrect MTU - Expected: {self.inputs.mtu} Actual: {values['mtu']}")
+        specific_interfaces = {intf: mtu for intf_mtu in self.inputs.specific_mtu for intf, mtu in intf_mtu.items()}
+
+        for interface, details in command_output["interfaces"].items():
+            # Verification is skipped if the interface is in the ignored interfaces list
+            if _is_interface_ignored(interface, self.inputs.ignored_interfaces) or details["forwardingModel"] != "routed":
+                continue
+
+            actual_mtu = details["mtu"]
+            expected_mtu = specific_interfaces.get(interface, self.inputs.mtu)
+
+            if (actual_mtu := details["mtu"]) != expected_mtu:
+                self.result.is_failure(f"Interface: {interface} - Incorrect MTU - Expected: {expected_mtu} Actual: {actual_mtu}")
 
 
 class VerifyIPProxyARP(AntaTest):
@@ -536,10 +647,9 @@ class VerifyIPProxyARP(AntaTest):
 
 
 class VerifyL2MTU(AntaTest):
-    """Verifies the global layer 2 Maximum Transfer Unit (MTU) for all L2 interfaces.
+    """Verifies the L2 MTU of bridged interfaces.
 
-    Test that L2 interfaces are configured with the correct MTU. It supports Ethernet, Port Channel and VLAN interfaces.
-    You can define a global MTU to check and also an MTU per interface and also ignored some interfaces.
+    Test that layer 2 (bridged) interfaces are configured with the correct MTU.
 
     Expected Results
     ----------------
@@ -551,10 +661,10 @@ class VerifyL2MTU(AntaTest):
     ```yaml
     anta.tests.interfaces:
       - VerifyL2MTU:
-          mtu: 1500
+          mtu: 9214
           ignored_interfaces:
-            - Management1
-            - Vxlan1
+            - Ethernet2/1
+            - Port-Channel  # Ignore all Port-Channel interfaces
           specific_mtu:
             - Ethernet1/1: 1500
     ```
@@ -568,28 +678,31 @@ class VerifyL2MTU(AntaTest):
         """Input model for the VerifyL2MTU test."""
 
         mtu: int = 9214
-        """Default MTU we should have configured on all non-excluded interfaces. Defaults to 9214."""
-        ignored_interfaces: list[str] = Field(default=["Management", "Loopback", "Vxlan", "Tunnel"])
-        """A list of L2 interfaces to ignore. Defaults to ["Management", "Loopback", "Vxlan", "Tunnel"]"""
+        """Expected L2 MTU configured on all non-excluded interfaces."""
+        ignored_interfaces: list[InterfaceType | Interface] = Field(default=["Dps", "Fabric", "Loopback", "Management", "Recirc-Channel", "Tunnel", "Vlan", "Vxlan"])
+        """A list of L2 interfaces or interface types like Ethernet, Port-Channel which will ignore all Ethernet and Port-Channel interfaces.
+
+        Takes precedence over the `specific_mtu` field."""
         specific_mtu: list[dict[Interface, int]] = Field(default=[])
-        """A list of dictionary of L2 interfaces with their specific MTU configured"""
+        """A list of dictionary of L2 interfaces with their expected L2 MTU configured."""
 
     @AntaTest.anta_test
     def test(self) -> None:
         """Main test function for VerifyL2MTU."""
         self.result.is_success()
         interface_output = self.instance_commands[0].json_output["interfaces"]
-        specific_interfaces = {key: value for details in self.inputs.specific_mtu for key, value in details.items()}
+        specific_interfaces = {intf: mtu for intf_mtu in self.inputs.specific_mtu for intf, mtu in intf_mtu.items()}
 
         for interface, details in interface_output.items():
-            catch_interface = re.findall(r"^[e,p][a-zA-Z]+[-,a-zA-Z]*\d+\/*\d*", interface, re.IGNORECASE)
-            if catch_interface and catch_interface not in self.inputs.ignored_interfaces and details["forwardingModel"] == "bridged":
-                if interface in specific_interfaces:
-                    if (mtu := specific_interfaces[interface]) != (act_mtu := details["mtu"]):
-                        self.result.is_failure(f"Interface: {interface} - Incorrect MTU configured - Expected: {mtu} Actual: {act_mtu}")
+            # Verification is skipped if the interface is in the ignored interfaces list
+            if _is_interface_ignored(interface, self.inputs.ignored_interfaces) or details["forwardingModel"] != "bridged":
+                continue
 
-                elif (act_mtu := details["mtu"]) != self.inputs.mtu:
-                    self.result.is_failure(f"Interface: {interface} - Incorrect MTU configured - Expected: {self.inputs.mtu} Actual: {act_mtu}")
+            actual_mtu = details["mtu"]
+            expected_mtu = specific_interfaces.get(interface, self.inputs.mtu)
+
+            if (actual_mtu := details["mtu"]) != expected_mtu:
+                self.result.is_failure(f"Interface: {interface} - Incorrect MTU - Expected: {expected_mtu} Actual: {actual_mtu}")
 
 
 class VerifyInterfaceIPv4(AntaTest):
