@@ -12,7 +12,7 @@ from typing import TYPE_CHECKING, ClassVar
 
 from pydantic import Field
 
-from anta.custom_types import Vlan, Vni, VxlanSrcIntf
+from anta.custom_types import VlanId, Vni, VxlanSrcIntf
 from anta.models import AntaCommand, AntaTest
 from anta.tools import get_value
 
@@ -102,11 +102,11 @@ class VerifyVxlanConfigSanity(AntaTest):
 
 
 class VerifyVxlanVniBinding(AntaTest):
-    """Verifies the VNI-VLAN bindings of the Vxlan1 interface.
+    """Verifies the VNI-VLAN, VNI-VRF bindings of the Vxlan1 interface.
 
     Expected Results
     ----------------
-    * Success: The test will pass if the VNI-VLAN bindings provided are properly configured.
+    * Success: The test will pass if the VNI-VLAN and VNI-VRF bindings provided are properly configured.
     * Failure: The test will fail if any VNI lacks bindings or if any bindings are incorrect.
     * Skipped: The test will be skipped if the Vxlan1 interface is not configured.
 
@@ -118,6 +118,7 @@ class VerifyVxlanVniBinding(AntaTest):
           bindings:
             10010: 10
             10020: 20
+            500: PROD
     ```
     """
 
@@ -127,8 +128,8 @@ class VerifyVxlanVniBinding(AntaTest):
     class Input(AntaTest.Input):
         """Input model for the VerifyVxlanVniBinding test."""
 
-        bindings: dict[Vni, Vlan]
-        """VNI to VLAN bindings to verify."""
+        bindings: dict[Vni, VlanId | str]
+        """VNI-VLAN or VNI-VRF bindings to verify."""
 
     @AntaTest.anta_test
     def test(self) -> None:
@@ -136,26 +137,32 @@ class VerifyVxlanVniBinding(AntaTest):
         self.result.is_success()
 
         if (vxlan1 := get_value(self.instance_commands[0].json_output, "vxlanIntfs.Vxlan1")) is None:
-            self.result.is_skipped("Vxlan1 interface is not configured")
+            self.result.is_skipped("Interface: Vxlan1 - Not configured")
             return
 
-        for vni, vlan in self.inputs.bindings.items():
+        for vni, vlan_vrf in self.inputs.bindings.items():
             str_vni = str(vni)
             retrieved_vlan = ""
-            if str_vni in vxlan1["vniBindings"]:
+            retrieved_vrf = ""
+            if all([str_vni in vxlan1["vniBindings"], isinstance(vlan_vrf, int)]):
                 retrieved_vlan = get_value(vxlan1, f"vniBindings..{str_vni}..vlan", separator="..")
             elif str_vni in vxlan1["vniBindingsToVrf"]:
-                retrieved_vlan = get_value(vxlan1, f"vniBindingsToVrf..{str_vni}..vlan", separator="..")
-
-            if not retrieved_vlan:
+                if isinstance(vlan_vrf, int):
+                    retrieved_vlan = get_value(vxlan1, f"vniBindingsToVrf..{str_vni}..vlan", separator="..")
+                else:
+                    retrieved_vrf = get_value(vxlan1, f"vniBindingsToVrf..{str_vni}..vrfName", separator="..")
+            if not any([retrieved_vlan, retrieved_vrf]):
                 self.result.is_failure(f"Interface: Vxlan1 VNI: {str_vni} - Binding not found")
 
-            elif vlan != retrieved_vlan:
-                self.result.is_failure(f"Interface: Vxlan1 VNI: {str_vni} VLAN: {vlan} - Wrong VLAN binding - Actual: {retrieved_vlan}")
+            elif retrieved_vlan and vlan_vrf != retrieved_vlan:
+                self.result.is_failure(f"Interface: Vxlan1 VNI: {str_vni} - Wrong VLAN binding - Expected: {vlan_vrf} Actual: {retrieved_vlan}")
+
+            elif retrieved_vrf and vlan_vrf != retrieved_vrf:
+                self.result.is_failure(f"Interface: Vxlan1 VNI: {str_vni} - Wrong VRF binding - Expected: {vlan_vrf} Actual: {retrieved_vrf}")
 
 
 class VerifyVxlanVtep(AntaTest):
-    """Verifies the VTEP peers of the Vxlan1 interface.
+    """Verifies Vxlan1 VTEP peers.
 
     Expected Results
     ----------------
@@ -191,7 +198,7 @@ class VerifyVxlanVtep(AntaTest):
         inputs_vteps = [str(input_vtep) for input_vtep in self.inputs.vteps]
 
         if (vxlan1 := get_value(self.instance_commands[0].json_output, "interfaces.Vxlan1")) is None:
-            self.result.is_skipped("Vxlan1 interface is not configured")
+            self.result.is_skipped("Interface: Vxlan1 - Not configured")
             return
 
         difference1 = set(inputs_vteps).difference(set(vxlan1["vteps"]))
@@ -205,7 +212,7 @@ class VerifyVxlanVtep(AntaTest):
 
 
 class VerifyVxlan1ConnSettings(AntaTest):
-    """Verifies the interface vxlan1 source interface and UDP port.
+    """Verifies Vxlan1 source interface and UDP port.
 
     Expected Results
     ----------------
@@ -243,7 +250,7 @@ class VerifyVxlan1ConnSettings(AntaTest):
         # Skip the test case if vxlan1 interface is not configured
         vxlan_output = get_value(command_output, "interfaces.Vxlan1")
         if not vxlan_output:
-            self.result.is_skipped("Vxlan1 interface is not configured.")
+            self.result.is_skipped("Interface: Vxlan1 - Not configured")
             return
 
         src_intf = vxlan_output.get("srcIpIntf")
